<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=hac
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'پاشەکۆتکەرڎەی و ئەۋەگېڵنای داتابەیسی بە فۆرماتو SQLite',
	'dump_slogan' => 'پاشەکۆتکەرڎەی و ئەۋەگېڵنای داتابەیسو SPIP',
];
